@@ -1,6 +1,6 @@
 
 
-import requests, json, datetime, asyncio, aiohttp
+import requests, json, datetime, aiohttp
 
 class Webhook():
     def __init__(self):
